\name{Brown}
\alias{Brown}
\title{Brown Corpus}
\description{
  The Brown University Standard Corpus of Present-Day American English.
}
\usage{
data("Brown")
}
\format{
  A \code{\link[tm:VCorpus]{Corpus}} of
  \link[NLP:TaggedTextDocument]{tagged text documents},
  using the Brown tagset (e.g.,
  \url{http://www.comp.leeds.ac.uk/ccalas/tagsets/brown.html}).
}
\details{
  The Brown Corpus contains 500 samples of English-language text,
  totaling roughly one million words, compiled from works published in
  the United States in 1961.  It was compiled in the 1960s by Henry
  Kucera and W. Nelson Francis at Brown University.
}
\references{
  \url{http://en.wikipedia.org/wiki/Brown_Corpus},
  \url{http://www.hit.uib.no/icame/brown/bcm.html}.
}
\source{
  http://www.nltk.org/nltk_data/
}
\examples{
data("Brown")
require("tm")
## Basic information:
Brown
Brown[[1L]]
## So we have a corpus (class: VCorpus) of 500 tagged text documents
## (class: TaggedTextDocument).
## The corpus provides document metadata for description and genre,
## as well as category (a simplified version of genre):
meta(Brown[[13]], type = "local")
## Frequencies of categories:
cats <- unlist(meta(Brown, tag = "category", type = "local"))
sort(table(cats))
## The text in tagged text documents can be accessed via the methods
## provided for text document viewers provided by package NLP:
require("NLP")
## E.g., to obtain the words in the first sentence of the first doc:
sents(Brown[[1L]])[[1L]]
## To obtain 15 the most frequent words in the first 10 documents:
w <- lapply(head(Brown, 10L), words)
head(sort(table(unlist(w)), decreasing=TRUE), 15L)
## To obtain the tagged words in the first sentence of the first doc:
tagged_sents(Brown[[1L]])[[1L]]
## To obtain the frequencies for the tags in the first 10 documents,
## we first get the tagged words:
w <- lapply(head(Brown, 10L), tagged_words)
## We then combine all these, and extract the tags:
tags <- sub(".*/", "", unlist(w))
## And finally, we compute the (sorted) frequencies:
sort(table(tags), decreasing = TRUE)
}
\keyword{datasets}
